@@ -1,25 +1,29 @@
-from redgrease import execute
-from redgrease.client import RedisGears
+import types
 from functools import lru_cache
 
+import redgrease
+from redgrease.client import RedisGears
+
 
 def runtime_execute_command(self, *args, **options):
     "Execute a command in local Gear runtime and return a parsed response"
     command_name = args[0]
-    response = execute(*args)
+    response = redgrease.execute(*args)
     if command_name in self.response_callbacks:
         return self.response_callbacks[command_name](response, **options)
     return response
 
 
-@lru_cache
+@lru_cache()
 def get_runtime_client():
     runtime_client = RedisGears(connection_pool=...)
-    runtime_client.execute_command = runtime_execute_command
+    runtime_client.execute_command = types.MethodType(
+        runtime_execute_command, runtime_client
+    )
     return runtime_client
 
 
-execute = get_runtime_client()  # noqa: F811 - Used as exported var
+api = get_runtime_client()  # noqa: F811 - Used as exported var
 
 
 # ## Redis v6 commands
